@@ -1,7 +1,9 @@
 import sys
 import os
 
-from urllib2 import urlopen, URLError
+import urlparse
+
+from urllib2 import urlopen, URLError, quote
 from pkg_resources import resource_filename
 
 from tiddlyweb.util import write_utf8_file, std_error_message
@@ -104,15 +106,21 @@ def cache_tiddlers(package_name):
         for uri in uris:
             filepath = os.path.join(bag_path, os.path.basename(uri))
             std_error_message("retrieving %s" % uri)
-            try:
-                content = urlopen(uri).read()
-                content = unicode(content, "utf-8")
-                write_utf8_file(filepath, content)
+            try: # XXX: duplication of tiddlywebplugins.twimport._get_url_handle
+                try:
+                    content = urlopen(uri).read()
+                except URLError:
+                    scheme, netloc, path, params, query, fragment = urlparse.urlparse(uri)
+                    path = quote(path)
+                    uri = urlparse.urlunparse((scheme, netloc, path, params, query, fragment))
+                    content = urlopen(uri).read()
             except URLError:
                 if uri.endswith(".meta"):
                     std_error_message("no meta file found for %s" % uri[:-5])
                 else:
                     raise
+            content = unicode(content, "utf-8")
+            write_utf8_file(filepath, content)
 
     tiddler_index = "tiddlers.index"
     tiddler_paths = []
